@@ -14,7 +14,8 @@
 
 from wsme import types as wtypes
 
-from octavia.api.v1.types import base
+from octavia.api.common import types as base
+from octavia.common import constants
 
 
 class MemberResponse(base.BaseType):
@@ -29,6 +30,8 @@ class MemberResponse(base.BaseType):
     project_id = wtypes.wsattr(wtypes.StringType())
     created_at = wtypes.wsattr(wtypes.datetime.datetime)
     updated_at = wtypes.wsattr(wtypes.datetime.datetime)
+    monitor_address = wtypes.wsattr(base.IPAddressType())
+    monitor_port = wtypes.wsattr(wtypes.IntegerType())
 
 
 class MemberPOST(base.BaseType):
@@ -39,7 +42,12 @@ class MemberPOST(base.BaseType):
     protocol_port = wtypes.wsattr(wtypes.IntegerType(), mandatory=True)
     weight = wtypes.wsattr(wtypes.IntegerType(), default=1)
     subnet_id = wtypes.wsattr(wtypes.UuidType())
+    # TODO(johnsom) Remove after deprecation (R series)
     project_id = wtypes.wsattr(wtypes.StringType(max_length=36))
+    monitor_port = wtypes.wsattr(wtypes.IntegerType(
+        minimum=constants.MIN_PORT_NUMBER, maximum=constants.MAX_PORT_NUMBER),
+        default=None)
+    monitor_address = wtypes.wsattr(base.IPAddressType(), default=None)
 
 
 class MemberPUT(base.BaseType):
@@ -47,3 +55,6 @@ class MemberPUT(base.BaseType):
     protocol_port = wtypes.wsattr(wtypes.IntegerType())
     enabled = wtypes.wsattr(bool)
     weight = wtypes.wsattr(wtypes.IntegerType())
+    monitor_address = wtypes.wsattr(base.IPAddressType())
+    monitor_port = wtypes.wsattr(wtypes.IntegerType(
+        minimum=constants.MIN_PORT_NUMBER, maximum=constants.MAX_PORT_NUMBER))
