@@ -32,7 +32,6 @@ from octavia.common import exceptions
 from octavia.common import validate
 from octavia.db import api as db_api
 from octavia.db import prepare as db_prepare
-from octavia.i18n import _
 
 
 CONF = cfg.CONF
@@ -93,18 +92,14 @@ class L7PolicyController(base.BaseController):
             raise exceptions.ImmutableObject(resource='Load Balancer',
                                              id=lb_id)
 
-    def _reset_lb_and_listener_statuses(self, session, lb_id, listener_id):
-        # Setting LB + listeners back to active because this should be a
-        # recoverable error
-        self.repositories.load_balancer.update(
-            session, lb_id,
-            provisioning_status=constants.ACTIVE)
-        self.repositories.listener.update(
-            session, listener_id,
-            provisioning_status=constants.ACTIVE)
-
     def _validate_create_l7policy(self, lock_session, l7policy_dict):
         try:
+            # Set the default HTTP redirect code here so it's explicit
+            if ((l7policy_dict.get('redirect_url') or
+                l7policy_dict.get('redirect_prefix')) and
+                    not l7policy_dict.get('redirect_http_code')):
+                l7policy_dict['redirect_http_code'] = 302
+
             return self.repositories.l7policy.create(lock_session,
                                                      **l7policy_dict)
         except odb_exceptions.DBDuplicateEntry:
@@ -115,23 +110,12 @@ class L7PolicyController(base.BaseController):
             # do not give any information as to what constraint failed
             raise exceptions.InvalidOption(value='', option='')
 
-    def _escape_l7policy_udp_pool_request(self, pool):
-        if pool.protocol == constants.PROTOCOL_UDP:
-            raise exceptions.ValidationException(
-                detail=_("%s protocol pool can not be assigned to "
-                         "l7policy.") % constants.PROTOCOL_UDP)
-
     @wsme_pecan.wsexpose(l7policy_types.L7PolicyRootResponse,
                          body=l7policy_types.L7PolicyRootPOST, status_code=201)
     def post(self, l7policy_):
         """Creates a l7policy on a listener."""
         l7policy = l7policy_.l7policy
         context = pecan.request.context.get('octavia_context')
-        # Make sure any pool specified by redirect_pool_id exists
-        if l7policy.redirect_pool_id:
-            db_pool = self._get_db_pool(
-                context.session, l7policy.redirect_pool_id)
-            self._escape_l7policy_udp_pool_request(db_pool)
         # Verify the parent listener exists
         listener_id = l7policy.listener_id
         listener = self._get_db_listener(
@@ -139,6 +123,11 @@ class L7PolicyController(base.BaseController):
         load_balancer_id = listener.load_balancer_id
         l7policy.project_id, provider = self._get_lb_project_id_provider(
             context.session, load_balancer_id)
+        # Make sure any pool specified by redirect_pool_id exists
+        if l7policy.redirect_pool_id:
+            db_pool = self._get_db_pool(
+                context.session, l7policy.redirect_pool_id)
+            self._validate_protocol(listener.protocol, db_pool.protocol)
 
         self._auth_validate_action(context, l7policy.project_id,
                                    constants.RBAC_POST)
@@ -218,13 +207,16 @@ class L7PolicyController(base.BaseController):
                 l7policy_dict[attr] = l7policy_dict.pop(val)
         sanitized_l7policy = l7policy_types.L7PolicyPUT(**l7policy_dict)
         context = pecan.request.context.get('octavia_context')
+
+        db_l7policy = self._get_db_l7policy(context.session, id,
+                                            show_deleted=False)
+        listener = self._get_db_listener(
+            context.session, db_l7policy.listener_id)
         # Make sure any specified redirect_pool_id exists
         if l7policy_dict.get('redirect_pool_id'):
             db_pool = self._get_db_pool(
                 context.session, l7policy_dict['redirect_pool_id'])
-            self._escape_l7policy_udp_pool_request(db_pool)
-        db_l7policy = self._get_db_l7policy(context.session, id,
-                                            show_deleted=False)
+            self._validate_protocol(listener.protocol, db_pool.protocol)
         load_balancer_id, listener_id = self._get_listener_and_loadbalancer_id(
             db_l7policy)
         project_id, provider = self._get_lb_project_id_provider(
