@@ -115,11 +115,7 @@ class ListenersController(base.BaseController):
         if not db_pool:
             raise exceptions.NotFound(
                 resource=data_models.Pool._name(), id=pool_id)
-        if (db_pool.protocol == constants.PROTOCOL_UDP and
-                db_pool.protocol != listener_protocol):
-            msg = _("Listeners of type %s can only have pools of "
-                    "type UDP.") % constants.PROTOCOL_UDP
-            raise exceptions.ValidationException(detail=msg)
+        self._validate_protocol(listener_protocol, db_pool.protocol)
 
     def _has_tls_container_refs(self, listener_dict):
         return (listener_dict.get('tls_certificate_id') or
@@ -375,9 +371,9 @@ class ListenersController(base.BaseController):
 
         # Make sure we have a client CA cert if they enable client auth
         if ((listener.client_authentication != wtypes.Unset and
-             listener.client_authentication != constants.CLIENT_AUTH_NONE)
-            and not (db_listener.client_ca_tls_certificate_id or
-                     listener.client_ca_tls_container_ref)):
+             listener.client_authentication != constants.CLIENT_AUTH_NONE) and
+            not (db_listener.client_ca_tls_certificate_id or
+                 listener.client_ca_tls_container_ref)):
             raise exceptions.ValidationException(detail=_(
                 "Client authentication setting %s requires a client CA "
                 "container reference.") %
@@ -480,15 +476,16 @@ class ListenersController(base.BaseController):
                 driver_utils.listener_dict_to_provider_dict(listener_dict))
 
             # Also prepare the baseline object data
-            old_provider_llistener = (
-                driver_utils.db_listener_to_provider_listener(db_listener))
+            old_provider_listener = (
+                driver_utils.db_listener_to_provider_listener(db_listener,
+                                                              for_delete=True))
 
             # Dispatch to the driver
             LOG.info("Sending update Listener %s to provider %s", id,
                      driver.name)
             driver_utils.call_provider(
                 driver.name, driver.listener_update,
-                old_provider_llistener,
+                old_provider_listener,
                 driver_dm.Listener.from_dict(provider_listener_dict))
 
             # Update the database to reflect what the driver just accepted
